from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .dead_letter_envelope import DeadLetterEnvelope

@dataclass
class DeadLetterEnvelopeResults(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: dict[str, Any] = field(default_factory=dict)

    # The databaseUri property
    database_uri: Optional[str] = None
    # The envelopes property
    envelopes: Optional[list[DeadLetterEnvelope]] = None
    # The pageNumber property
    page_number: Optional[int] = None
    # The totalCount property
    total_count: Optional[int] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> DeadLetterEnvelopeResults:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: DeadLetterEnvelopeResults
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return DeadLetterEnvelopeResults()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .dead_letter_envelope import DeadLetterEnvelope

        from .dead_letter_envelope import DeadLetterEnvelope

        fields: dict[str, Callable[[Any], None]] = {
            "databaseUri": lambda n : setattr(self, 'database_uri', n.get_str_value()),
            "envelopes": lambda n : setattr(self, 'envelopes', n.get_collection_of_object_values(DeadLetterEnvelope)),
            "pageNumber": lambda n : setattr(self, 'page_number', n.get_int_value()),
            "totalCount": lambda n : setattr(self, 'total_count', n.get_int_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("databaseUri", self.database_uri)
        writer.write_collection_of_object_values("envelopes", self.envelopes)
        writer.write_int_value("pageNumber", self.page_number)
        writer.write_int_value("totalCount", self.total_count)
        writer.write_additional_data_value(self.additional_data)
    

